//
//  GameController.m
//  Auto Layout demo
//
//  Created by Bertils mini on 2013-11-23.
//  Copyright (c) 2013 Sork Software. All rights reserved.
//

#import "DemoController.h"
#import "PlayerCentral.h"
#import "TitleView.h"
#import "SSMotionEffectSimple.h"

NSString *MoveNotification = @"Text Moved";

@implementation DemoController

#pragma mark - View lifecycle

- (void)viewDidLoad
{
  [super viewDidLoad];
  
  /* The views involved
   GameController subviews
   <PlayerCentral: 0x899cbe0; frame = (224 352; 320 320)
   <UIButton: 0x899ab10; frame = (361 894; 72 41)
   <_UILayoutGuide: 0xa1d3320; frame = (0 0; 0 0)
   <_UILayoutGuide: 0xa1d3630; frame = (0 0; 0 0)
   
   PlayerCentral subviews
   <PlaceView: 0x78792f40; frame = (47 47; 226 226)
   <PlayerView: 0x78794dc0; frame = (0 0; 273 47)
   <PlayerView: 0x7917b1c0; frame = (113 -113; 47 273); transform = [0, -1, 1, 0, 0, 0]
   <PlayerView: 0x7917b4c0; frame = (0 0; 273 47); transform = [-1, -0, 0, -1, 0, 0]
   <PlayerView: 0x7917e0b0; frame = (113 -113; 47 273); transform = [-0, 1, -1, -0, 0, 0]
   */
  
  // Lay out the player views with the help of auto layout
  [self.playerCentral layoutPlayerViews];
  
  // Create our simplistic ME subclass thingy and add it to the titleView
  [self.largeTitle addMotionEffect:[[SSMotionEffectSimple alloc] init]];
  
  // Listen to notifications from the ME subclass and update the titleView
  [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(deviceMoved:)
                                               name:MoveNotification object:nil];
}

#pragma mark - Notifications

// The user moved the device
- (void)deviceMoved:(NSNotification *)notification {
	// Get the move from the notifications userInfo
  NSValue *theMove = [[notification userInfo] objectForKey:@"Offset"];
  CGPoint thePoint = [theMove CGPointValue];
  
  // Update the drawing with the new offsets
  self.largeTitle.offsets = thePoint;
  
  [self.largeTitle setNeedsDisplay];
}

#pragma mark - Action methods

// Toggle the central size between the iPhone's 320 px and something slightly larger
- (IBAction)toggleLayout:(UIButton *)sender
{
  NSArray *pcCons = self.playerCentral.constraints;
  NSLayoutConstraint *aCon;
  CGFloat newSize = 375;
  
  for (aCon in pcCons)
  {
    if (aCon.firstAttribute == NSLayoutAttributeWidth)
    {
      if (aCon.constant == 320) {
        aCon.constant = newSize;
      }
      else {
        aCon.constant = 320;
      }
    }
    if (aCon.firstAttribute == NSLayoutAttributeHeight)
    {
      if (aCon.constant == 320) {
        aCon.constant = newSize;
      }
      else {
        aCon.constant = 320;
      }
    }
  }
}

@end
