//
//  PlayerView.m
//  Auto Layout demo
//
//  Holds a LED lamp, a static player name and a dynamic score count
//
//  Created by Bertils mini on 2010-01-16.
//  Copyright 2010-14 Sork Software. All rights reserved.
//
//  Version 1.3 modifies layoutSubviews with corrections for the problems added by iOS 8. Nov 2014
//

#import "PlayerView.h"
#import "PlayerCentral.h"

@implementation PlayerView

- (id)initWithCoder:(NSCoder*)coder {
  if (self = [super initWithCoder:coder]) {
    // We add the external constraints manually in the player central
    self.translatesAutoresizingMaskIntoConstraints = NO;
  }
  return self;
}

/* PV constraints added in IB
 "<NSLayoutConstraint:0x78e73ac0 V:[UIImageView:0x7a1abee0]-(0)-|   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73af0 H:|-(0)-[UIImageView:0x7a1abee0]   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73b20 H:[UIImageView:0x7a1abee0]-(0)-|   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73b50 V:|-(0)-[UIImageView:0x7a1abee0]   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73b80 H:|-(0)-[UIImageView:0x78e70530]   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73bb0 PlayerView:0x7a1ab990.centerY == UIImageView:0x78e70530.centerY>",
 "<NSLayoutConstraint:0x78e73be0 PlayerView:0x7a1ab990.centerY == UILabel:0x78e70f60'Player bar'.centerY>",
 "<NSLayoutConstraint:0x78e73c10 H:[UIImageView:0x78e70530]-(NSSpace(8))-[UILabel:0x78e70f60'Player bar']>",
 "<NSLayoutConstraint:0x78e73c60 V:|-(6)-[UILabel:0x78e72540'000']   (Names: '|':PlayerView:0x7a1ab990 )>",
 "<NSLayoutConstraint:0x78e73c90 H:[UILabel:0x78e72540'000']-(8)-|   (Names: '|':PlayerView:0x7a1ab990 )>"
*/

// Correct the frames after the iOS 8 auto layout interference
// Also set the indicator lamp subview horizontal position when the view width changes
- (void)layoutSubviews {
  [super layoutSubviews];
  
  // The parameters of the unrotated first player view #0 that will change with the screen width
  PlayerView *baseView = [self.playerCentral playerViewWithTag:0];
  CGFloat baseWidth = baseView.frame.size.width;
  CGFloat baseHeight = baseView.frame.size.height;
  CGFloat centralWidth = self.superview.frame.size.width;
  
  // The first, righthand, vertical view #1
  if (self.tag == 1) {
    CGRect frame1 = CGRectMake(centralWidth - baseHeight, baseHeight, baseHeight, baseWidth);
    self.frame = frame1; // {273, 47}, {47, 273}
  }
  
  // The other, lefthand, vertical view #3
  if (self.tag == 3) {
    CGRect frame3 = CGRectMake(0, 0, baseHeight, baseWidth);
    self.frame = frame3; // {0, 0}, {47, 273}
  }
  
  // Use the basic size to frame the player view background view image
  CGRect highFrame = CGRectMake(0.0, 0.0, baseWidth, baseHeight);
  self.playerHighlight.frame = highFrame;

  // Set the corrected and adjusted ver and hor offset of the square lamp view
  CGFloat lampOffset = (highFrame.size.height - self.playerIndicator.frame.size.height) / 2;
  CGRect lampFrame = CGRectMake(lampOffset, lampOffset, 47.0, 47.0);
  self.playerIndicator.frame = lampFrame;
  
  // Calculate the correct position for the score label and adjust its font size
  UIFont *scoreFont;
  if (baseHeight > 47.0) {
    scoreFont = [UIFont fontWithName:@"DBLCDTempBlack" size:45]; // char height 72
  } else {
    scoreFont = [UIFont fontWithName:@"DBLCDTempBlack" size:36]; // char height 58
  }
  self.scoreLabel.font = scoreFont;
  
  // This is the size of the label
  self.scoreSize = self.scoreLabel.frame.size;

  // The score label is anchored to the left side of the player view at the standard gap
  CGFloat scoreHorPos = baseWidth - self.scoreSize.width - 8.0;
  CGFloat scoreVerPos = 3.5 + (baseHeight - self.scoreSize.height) / 2;
  CGRect scoreFrame = CGRectMake(scoreHorPos, scoreVerPos, self.scoreSize.width, self.scoreSize.height);
  self.scoreLabel.frame = scoreFrame;
  
  // Adjust the size and position of the player title label and adjust its font size
  UIFont *playerFont;
  if (baseHeight > 47.0) {
    playerFont = [UIFont boldSystemFontOfSize:31];
  } else {
    playerFont = [UIFont boldSystemFontOfSize:25];
  }
  self.playerLabel.font = playerFont;
  
  // The labels will have different sizes
  self.titleSize = self.playerLabel.frame.size;
  
  // The title label is anchored to the right of the indicator with the standard distance
  CGFloat titleVerPos = (baseHeight - self.titleSize.height) / 2; // 9.5
  CGFloat titleHorPos = self.playerIndicator.frame.size.width + self.playerIndicator.frame.origin.x + 8.0; // 55/69
  CGRect titleFrame = CGRectMake(titleHorPos, titleVerPos, self.titleSize.width, self.titleSize.height);
  self.playerLabel.frame = titleFrame;
  
  [self layoutIfNeeded];
}

@end
